/**
 * @file dmxprogram.h
 * @author Florian Schmitt <florian.schmitt@qikgrp.com>
 * ----------------------------------------------------------------------------
 * (c) Florian Schmitt / 2012-2013
 * License GPLv3+: GNU GPL Version 3 
 * or higher <http://gnu.org/licenses/gpl.html>
 * This code comes with ABSOLUTELY NO WARRANTY. This is free software, and 
 * you are welcome to redistribute it under certain conditions.
 * ----------------------------------------------------------------------------
 * Represents a DMX program
**/
#ifndef DMXPROGRAM_H
#define DMXPROGRAM_H
/* needed includes */
#include "dmxcue.h"
#include <stdio.h>
#define DMXPROGRAM_NAME_LEN       35
#define DMXPROGRAM_STEPLEN_MAX   512
#define DMXPROGRAM_STEPLEN_MIN  -128

/**
 * Represents a program
**/
typedef struct dmxprogram {
	/* an array of dmxlist_t-pointers */
	dmxlist_t **data;
	/* step speed (length of one step) - steplen<0 means 1/(-steplen)*/
	long int steplen;
	/* current position */
	int pos;
	/* program size / data array size */
	int size;
	/* master fade value */
	int fade;
	/* program is active */
	int active;
	/* program wants to be send */
	int refresh;
	/* if set, the program will trigger onbeat */
	int trigger;
	/* Group number */
	int group;
	/* program name */
	char name[DMXPROGRAM_NAME_LEN];
} dmxprogram_t;



/* Creates a new dmxprogram_t object */
dmxprogram_t *dmxprogram_create();
/* Cleans up */
void dmxprogram_destroy(dmxprogram_t*);
/* Appends a cue to cue list */
int dmxprogram_append(dmxlist_t*, dmxprogram_t*);
/* Appends a empty, new cue to cue list */
int dmxprogram_append_new(dmxprogram_t*);
/* dmxprogram_get_cue() */
dmxlist_t *dmxprogram_get_cue(int, dmxprogram_t*);
/* get CURRENT cue */
dmxlist_t *dmxprogram_get_current_cue(dmxprogram_t*);
/* goes one step up */
void dmxprogram_step_up(dmxprogram_t*);
/* saves program into a file */
long dmxprogram_save(FILE*, dmxprogram_t*);
/* loads program from a file */
long dmxprogram_load(FILE*, dmxprogram_t*);
/* increases the speed of a program */
void dmxprogram_speed_set(dmxprogram_t*, long int);
/* increases the speed of a program [TAKE CARE: SPEED AND STEPLEN ARE 1/x] */
void dmxprogram_speed_increase(dmxprogram_t*);
/* decreases the speed of a program */
void dmxprogram_speed_decrease(dmxprogram_t*);
/* sets the name of a program */
void dmxprogram_set_name(dmxprogram_t*, const char*);


#endif /* DMXPROGRAM_H */
